@@ -7,9 +7,11 @@ import hashlib
 import hmac
 
 try:
+    import urllib.parse as urlparse
     from urllib.parse import urlencode
 except ImportError:
     from urllib import urlencode
+    import urlparse
 from decimal import Decimal
 
 import six
@@ -18,11 +20,12 @@ from facepy.exceptions import *
 
 
 class GraphAPI(object):
-    def __init__(self, oauth_token=False, url='https://graph.facebook.com', verify_ssl_certificate=True, appsecret=False, timeout=None):
+    def __init__(self, oauth_token=False, url='https://graph.facebook.com', verify_ssl_certificate=True, appsecret=False, timeout=None, version=None):
         """
         Initialize GraphAPI with an OAuth access token.
 
         :param oauth_token: A string describing an OAuth access token.
+        :param version: A string with version ex. '2.2'.
         """
         self.oauth_token = oauth_token
         self.session = requests.session()
@@ -30,9 +33,10 @@ class GraphAPI(object):
         self.verify_ssl_certificate = verify_ssl_certificate
         self.appsecret = appsecret
         self.timeout = timeout
+        self.version = version
 
     @classmethod
-    def for_application(self, id, secret_key):
+    def for_application(self, id, secret_key, api_version=None):
         """
         Initialize GraphAPI with an OAuth access token for an application.
 
@@ -41,7 +45,8 @@ class GraphAPI(object):
         """
         from facepy.utils import get_application_access_token
 
-        return GraphAPI(get_application_access_token(id, secret_key))
+        access_token = get_application_access_token(id, secret_key, api_version=api_version)
+        return GraphAPI(access_token, version=api_version)
 
     def get(self, path='', page=False, retry=3, **options):
         """
@@ -312,7 +317,7 @@ class GraphAPI(object):
             else:
                 path = '/' + path
 
-        url = '%s%s' % (self.url, path)
+        url = self._get_url(path)
 
         if self.oauth_token:
             data['access_token'] = self.oauth_token
@@ -331,6 +336,22 @@ class GraphAPI(object):
             else:
                 raise
 
+    def _get_url(self, path):
+        # When Facebook returns nested resources (like comments for a post), it
+        # prepends 'https://graph.facebook.com' by itself and so we must take
+        # care not to prepend it again.
+        if urlparse.urlparse(path).netloc == '':
+            url = self.url
+        else:
+            url = ''
+
+        if self.version:
+            url = '%s/v%s%s' % (url, self.version, path)
+        else:
+            url = '%s%s' % (url, path)
+
+        return url
+
     def _parse(self, data):
         """
         Parse the response from Facebook's Graph API.
